# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_empty.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Nothing",
    "MaybeNothing",
    "Test",
)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Nothing(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class MaybeNothing(betterproto.Message):
    """ """

    sometimes: str = betterproto.string_field(42)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    nothing: "Nothing" = betterproto.message_field(1, group="empty")
    """
    
    """

    maybe1: "MaybeNothing" = betterproto.message_field(2, group="empty")
    """
    
    """

    maybe2: "MaybeNothing" = betterproto.message_field(3, group="empty")
    """
    
    """
