# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12(service_separate_packages.things.service\x1a\x0emessages.proto2\xb7\x04\n\x04Test\x12\x80\x01\n\x07\x44oThing\x12\x39.service_separate_packages.things.messages.DoThingRequest\x1a:.service_separate_packages.things.messages.DoThingResponse\x12\x87\x01\n\x0c\x44oManyThings\x12\x39.service_separate_packages.things.messages.DoThingRequest\x1a:.service_separate_packages.things.messages.DoThingResponse(\x01\x12\x8d\x01\n\x10GetThingVersions\x12:.service_separate_packages.things.messages.GetThingRequest\x1a;.service_separate_packages.things.messages.GetThingResponse0\x01\x12\x91\x01\n\x12GetDifferentThings\x12:.service_separate_packages.things.messages.GetThingRequest\x1a;.service_separate_packages.things.messages.GetThingResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=76
  _globals['_TEST']._serialized_end=643
# @@protoc_insertion_point(module_scope)
