# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested2.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "GamePlayerRace",
    "Game",
    "GamePlayer",
    "Test",
)


from dataclasses import dataclass

import betterproto_fw


class GamePlayerRace(betterproto_fw.Enum):
    """ """

    human = 0
    """
    
    """

    orc = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Game(betterproto_fw.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class GamePlayer(betterproto_fw.Message):
    """ """

    pass


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    game: "Game" = betterproto_fw.message_field(1)
    """
    
    """

    game_player: "GamePlayer" = betterproto_fw.message_field(2)
    """
    
    """

    game_player_race: "GamePlayerRace" = betterproto_fw.enum_field(3)
    """
    
    """

    weapon: "equipment.Weapon" = betterproto_fw.message_field(4)
    """
    
    """


from . import equipment
