# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto3_field_presence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'proto3_field_presence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bproto3_field_presence.proto\x12\x15proto3_field_presence\x1a\x1fgoogle/protobuf/timestamp.proto\"\x19\n\tInnerTest\x12\x0c\n\x04test\x18\x01 \x01(\t\"\xf3\x02\n\x04Test\x12\x12\n\x05test1\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x12\n\x05test2\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x12\n\x05test3\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05test4\x18\x04 \x01(\x0cH\x03\x88\x01\x01\x12\x34\n\x05test5\x18\x05 \x01(\x0b\x32 .proto3_field_presence.InnerTestH\x04\x88\x01\x01\x12\x33\n\x05test6\x18\x06 \x01(\x0e\x32\x1f.proto3_field_presence.TestEnumH\x05\x88\x01\x01\x12\x12\n\x05test7\x18\x07 \x01(\x04H\x06\x88\x01\x01\x12\x12\n\x05test8\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12.\n\x05test9\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x42\x08\n\x06_test1B\x08\n\x06_test2B\x08\n\x06_test3B\x08\n\x06_test4B\x08\n\x06_test5B\x08\n\x06_test6B\x08\n\x06_test7B\x08\n\x06_test8B\x08\n\x06_test9*\x18\n\x08TestEnum\x12\x05\n\x01\x41\x10\x00\x12\x05\n\x01\x42\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto3_field_presence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TESTENUM']._serialized_start=488
  _globals['_TESTENUM']._serialized_end=512
  _globals['_INNERTEST']._serialized_start=87
  _globals['_INNERTEST']._serialized_end=112
  _globals['_TEST']._serialized_start=115
  _globals['_TEST']._serialized_end=486
# @@protoc_insertion_point(module_scope)
