# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Verify that we can import root message from child package"""

    message: "__import_root_package_from_child__.RootMessage" = (
        betterproto.message_field(1)
    )
    """
    
    """


from ... import import_root_package_from_child as __import_root_package_from_child__
