# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof_default_value_serialization.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof_default_value_serialization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'oneof_default_value_serialization.proto\x12!oneof_default_value_serialization\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x18\n\x07Message\x12\r\n\x05value\x18\x01 \x01(\x03\"v\n\rNestedMessage\x12\n\n\x02id\x18\x01 \x01(\x03\x12K\n\x15wrapped_message_value\x18\x02 \x01(\x0b\x32*.oneof_default_value_serialization.MessageH\x00\x42\x0c\n\nvalue_type\"\x8e\x03\n\x04Test\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x02 \x01(\x03H\x00\x12\x35\n\x0ftimestamp_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x33\n\x0e\x64uration_value\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12K\n\x15wrapped_message_value\x18\x05 \x01(\x0b\x32*.oneof_default_value_serialization.MessageH\x00\x12X\n\x1cwrapped_nested_message_value\x18\x06 \x01(\x0b\x32\x30.oneof_default_value_serialization.NestedMessageH\x00\x12\x38\n\x12wrapped_bool_value\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueH\x00\x42\x0c\n\nvalue_typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_default_value_serialization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MESSAGE']._serialized_start=175
  _globals['_MESSAGE']._serialized_end=199
  _globals['_NESTEDMESSAGE']._serialized_start=201
  _globals['_NESTEDMESSAGE']._serialized_end=319
  _globals['_TEST']._serialized_start=322
  _globals['_TEST']._serialized_end=720
# @@protoc_insertion_point(module_scope)
