# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_service_returns_googletype.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_service_returns_googletype.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,googletypes_service_returns_googletype.proto\x12&googletypes_service_returns_googletype\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x10\n\x0eRequestMessage2\x80\x03\n\x04Test\x12Z\n\x08GetEmpty\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x16.google.protobuf.Empty\x12\\\n\tGetStruct\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x17.google.protobuf.Struct\x12\x62\n\x0cGetListValue\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x1a.google.protobuf.ListValue\x12Z\n\x08GetValue\x12\x36.googletypes_service_returns_googletype.RequestMessage\x1a\x16.google.protobuf.Valueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_service_returns_googletype_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REQUESTMESSAGE']._serialized_start=147
  _globals['_REQUESTMESSAGE']._serialized_end=163
  _globals['_TEST']._serialized_start=166
  _globals['_TEST']._serialized_end=550
# @@protoc_insertion_point(module_scope)
