# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: empty_service.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestStub",
    "TestBase",
)


from typing import (
    Dict,
)

import grpclib

import betterproto_fw
from betterproto_fw.grpc.grpclib_server import ServiceBase


class TestStub(betterproto_fw.ServiceStub):
    """ """


class TestBase(ServiceBase):
    """ """

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {}
