# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: double.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    count: float = betterproto.double_field(1)
    """
    
    """
