# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "TestMsg",
    "Test",
    "TestNested",
    "Sibling",
)


from dataclasses import dataclass

import betterproto_fw


class TestMsg(betterproto_fw.Enum):
    """This is the nested enum."""

    NONE = 0
    """
    
    """

    THIS = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """A test message with a nested message inside of it."""

    nested: "TestNested" = betterproto_fw.message_field(1)
    """
    
    """

    sibling: "Sibling" = betterproto_fw.message_field(2)
    """
    
    """

    sibling2: "Sibling" = betterproto_fw.message_field(3)
    """
    
    """

    msg: "TestMsg" = betterproto_fw.enum_field(4)
    """
    
    """


@dataclass(eq=False, repr=False)
class TestNested(betterproto_fw.Message):
    """This is the nested type."""

    count: int = betterproto_fw.int32_field(1)
    """Stores a simple counter."""


@dataclass(eq=False, repr=False)
class Sibling(betterproto_fw.Message):
    """ """

    foo: int = betterproto_fw.int32_field(1)
    """
    
    """
