# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_parent_package_from_child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests generated imports when a message refers to a message defined in its parent package
    """

    message_implicit: "__parent__.ParentPackageMessage" = betterproto_fw.message_field(
        1
    )
    """
    
    """

    message_explicit: "__parent__.ParentPackageMessage" = betterproto_fw.message_field(
        2
    )
    """
    
    """


from ... import parent as __parent__
