# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: regression_387.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "ParentElement",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    id: int = betterproto.uint64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class ParentElement(betterproto.Message):
    """ """

    name: str = betterproto.string_field(1)
    """
    
    """

    elems: List["Test"] = betterproto.message_field(2)
    """
    
    """
