# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_parent_package_from_child.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    Tests generated imports when a message refers to a message defined in its parent package
    """

    message_implicit: "__parent__.ParentPackageMessage" = betterproto.message_field(1)
    """
    
    """

    message_explicit: "__parent__.ParentPackageMessage" = betterproto.message_field(2)
    """
    
    """


from ... import parent as __parent__
