# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: field_name_identical_to_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'field_name_identical_to_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"field_name_identical_to_type.proto\x12\x1c\x66ield_name_identical_to_type\"L\n\x04Test\x12\x0b\n\x03int\x18\x01 \x01(\x05\x12\r\n\x05\x66loat\x18\x02 \x01(\x02\x12\x0b\n\x03str\x18\x03 \x01(\t\x12\r\n\x05\x62ytes\x18\x04 \x01(\x0c\x12\x0c\n\x04\x62ool\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'field_name_identical_to_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=68
  _globals['_TEST']._serialized_end=144
# @@protoc_insertion_point(module_scope)
