# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_root_sibling.proto, sibling.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "SiblingMessage",
    "Test",
)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class SiblingMessage(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """
    Tests generated imports when a message in the root package refers to another message in the root package
    """

    sibling: "SiblingMessage" = betterproto.message_field(1)
    """
    
    """
