# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google_impl_behavior_equivalence.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Foo",
    "Test",
    "Spam",
    "Request",
    "Empty",
)


from dataclasses import dataclass
from datetime import datetime

import betterproto_fw


@dataclass(eq=False, repr=False)
class Foo(betterproto_fw.Message):
    """ """

    bar: int = betterproto_fw.int64_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    string: str = betterproto_fw.string_field(1, group="group")
    """
    
    """

    integer: int = betterproto_fw.int64_field(2, group="group")
    """
    
    """

    foo: "Foo" = betterproto_fw.message_field(3, group="group")
    """
    
    """


@dataclass(eq=False, repr=False)
class Spam(betterproto_fw.Message):
    """ """

    ts: datetime = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Request(betterproto_fw.Message):
    """ """

    foo: "Empty" = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Empty(betterproto_fw.Message):
    """ """

    pass
