# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests that we can import from a package with a capital name, that looks like a nested type, but isn't.
    """

    message: "CapitalizedMessage" = betterproto_fw.message_field(1)
    """
    
    """
