# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: signed.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    signed32: int = betterproto.sint32_field(1)
    """
    todo: rename fields after fixing bug where 'signed_32_positive' will map to 'signed_32Positive' as output json
    
     signed_32_positive
    """

    negative32: int = betterproto.sint32_field(2)
    """ signed_32_negative"""

    string64: int = betterproto.sint64_field(3)
    """ signed_64_positive"""

    negative64: int = betterproto.sint64_field(4)
    """ signed_64_negative"""
