# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: nested2.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "GamePlayerRace",
    "Game",
    "GamePlayer",
    "Test",
)


from pydantic.dataclasses import dataclass

import betterproto


class GamePlayerRace(betterproto.Enum):
    """ """

    human = 0
    """
    
    """

    orc = 1
    """
    
    """

    @classmethod
    def __get_pydantic_core_schema__(cls, _source_type, _handler):
        from pydantic_core import core_schema

        return core_schema.int_schema(ge=0)


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Game(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GamePlayer(betterproto.Message):
    """ """

    pass


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    game: "Game" = betterproto.message_field(1)
    """
    
    """

    game_player: "GamePlayer" = betterproto.message_field(2)
    """
    
    """

    game_player_race: "GamePlayerRace" = betterproto.enum_field(3)
    """
    
    """

    weapon: "equipment.Weapon" = betterproto.message_field(4)
    """
    
    """


from . import equipment
