# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: deprecated.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'deprecated.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x64\x65precated.proto\x12\ndeprecated\"?\n\x04Test\x12(\n\x07message\x18\x01 \x01(\x0b\x32\x13.deprecated.MessageB\x02\x18\x01\x12\r\n\x05value\x18\x02 \x01(\x05\"\x1c\n\x07Message\x12\r\n\x05value\x18\x01 \x01(\t:\x02\x18\x01\"\x07\n\x05\x45mpty2y\n\x0bTestService\x12,\n\x04\x66unc\x12\x11.deprecated.Empty\x1a\x11.deprecated.Empty\x12<\n\x0f\x64\x65precated_func\x12\x11.deprecated.Empty\x1a\x11.deprecated.Empty\"\x03\x88\x02\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deprecated_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST'].fields_by_name['message']._loaded_options = None
  _globals['_TEST'].fields_by_name['message']._serialized_options = b'\030\001'
  _globals['_MESSAGE']._loaded_options = None
  _globals['_MESSAGE']._serialized_options = b'\030\001'
  _globals['_TESTSERVICE'].methods_by_name['deprecated_func']._loaded_options = None
  _globals['_TESTSERVICE'].methods_by_name['deprecated_func']._serialized_options = b'\210\002\001'
  _globals['_TEST']._serialized_start=32
  _globals['_TEST']._serialized_end=95
  _globals['_MESSAGE']._serialized_start=97
  _globals['_MESSAGE']._serialized_end=125
  _globals['_EMPTY']._serialized_start=127
  _globals['_EMPTY']._serialized_end=134
  _globals['_TESTSERVICE']._serialized_start=136
  _globals['_TESTSERVICE']._serialized_end=257
# @@protoc_insertion_point(module_scope)
