# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: int32.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """Some documentation about the Test message."""

    positive: int = betterproto.int32_field(1)
    """Some documentation about the count."""

    negative: int = betterproto.int32_field(2)
    """
    
    """
