# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: oneof.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'oneof.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0boneof.proto\x12\x05oneof\"\x1b\n\nMixedDrink\x12\r\n\x05shots\x18\x01 \x01(\x05\"\xa6\x01\n\x04Test\x12\x10\n\x06pitied\x18\x01 \x01(\x05H\x00\x12\x10\n\x06pitier\x18\x02 \x01(\tH\x00\x12\x1c\n\x14just_a_regular_field\x18\x03 \x01(\x05\x12\x10\n\x06\x64rinks\x18\x0b \x01(\x05H\x01\x12\x12\n\x08\x62\x61r_name\x18\x0c \x01(\tH\x01\x12(\n\x0bmixed_drink\x18\r \x01(\x0b\x32\x11.oneof.MixedDrinkH\x01\x42\x05\n\x03\x66ooB\x05\n\x03\x62\x61rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oneof_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MIXEDDRINK']._serialized_start=22
  _globals['_MIXEDDRINK']._serialized_end=49
  _globals['_TEST']._serialized_start=52
  _globals['_TEST']._serialized_end=218
# @@protoc_insertion_point(module_scope)
