# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_value.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17googletypes_value.proto\x12\x11googletypes_value\x1a\x1cgoogle/protobuf/struct.proto\"\xce\x01\n\x04Test\x12&\n\x06value1\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value2\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value3\x18\x03 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value4\x18\x04 \x01(\x0b\x32\x16.google.protobuf.Value\x12&\n\x06value5\x18\x05 \x01(\x0b\x32\x16.google.protobuf.Valueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=77
  _globals['_TEST']._serialized_end=283
# @@protoc_insertion_point(module_scope)
