# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: googletypes_value.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """
    Tests that fields of type google.protobuf.Value can contain arbitrary JSON-values.
    """

    value1: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(1)
    )
    """
    
    """

    value2: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(2)
    )
    """
    
    """

    value3: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(3)
    )
    """
    
    """

    value4: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(4)
    )
    """
    
    """

    value5: "betterproto_fw_lib_pydantic_google_protobuf.Value" = (
        betterproto_fw.message_field(5)
    )
    """
    
    """


import betterproto_fw.lib.pydantic.google.protobuf as betterproto_fw_lib_pydantic_google_protobuf
