# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Sub",
)


from dataclasses import dataclass
from typing import (
    List,
)

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """ """

    greetings: List["Sub"] = betterproto_fw.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False)
class Sub(betterproto_fw.Message):
    """ """

    greeting: str = betterproto_fw.string_field(1)
    """
    
    """
