# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: casing.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'casing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63\x61sing.proto\x12\x06\x63\x61sing\"\x89\x01\n\x04Test\x12\x11\n\tcamelCase\x18\x01 \x01(\x05\x12#\n\nsnake_case\x18\x02 \x01(\x0e\x32\x0f.casing.my_enum\x12\x36\n\x12snake_case_message\x18\x03 \x01(\x0b\x32\x1a.casing.snake_case_message\x12\x11\n\tUPPERCASE\x18\x04 \x01(\x05\"\x14\n\x12snake_case_message*%\n\x07my_enum\x12\x08\n\x04ZERO\x10\x00\x12\x07\n\x03ONE\x10\x01\x12\x07\n\x03TWO\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'casing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MY_ENUM']._serialized_start=186
  _globals['_MY_ENUM']._serialized_end=223
  _globals['_TEST']._serialized_start=25
  _globals['_TEST']._serialized_end=162
  _globals['_SNAKE_CASE_MESSAGE']._serialized_start=89
  _globals['_SNAKE_CASE_MESSAGE']._serialized_end=109
# @@protoc_insertion_point(module_scope)
