# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: float.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto_fw.Message):
    """Some documentation about the Test message."""

    positive: float = betterproto_fw.double_field(1)
    """
    
    """

    negative: float = betterproto_fw.double_field(2)
    """
    
    """

    nan: float = betterproto_fw.double_field(3)
    """
    
    """

    three: float = betterproto_fw.double_field(4)
    """
    
    """

    three_point_one_four: float = betterproto_fw.double_field(5)
    """
    
    """

    neg_three: float = betterproto_fw.double_field(6)
    """
    
    """

    neg_three_point_one_four: float = betterproto_fw.double_field(7)
    """
    
    """
