# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: test.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Verify that we can import a message unrelated to us, in a subpackage with the same name as us.
    """

    message: "__cousin_subpackage__.CousinMessage" = betterproto_fw.message_field(1)
    """
    
    """


from ...cousin import subpackage as __cousin_subpackage__
