# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: enum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'enum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nenum.proto\x12\x04\x65num\"C\n\x04Test\x12\x1c\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x0c.enum.Choice\x12\x1d\n\x07\x63hoices\x18\x02 \x03(\x0e\x32\x0c.enum.Choice*0\n\x06\x43hoice\x12\x08\n\x04ZERO\x10\x00\x12\x07\n\x03ONE\x10\x01\x12\x08\n\x04\x46OUR\x10\x04\x12\t\n\x05THREE\x10\x03*\x93\x01\n\x12\x41rithmeticOperator\x12\x1c\n\x18\x41RITHMETIC_OPERATOR_NONE\x10\x00\x12\x1c\n\x18\x41RITHMETIC_OPERATOR_PLUS\x10\x01\x12\x1d\n\x19\x41RITHMETIC_OPERATOR_MINUS\x10\x02\x12\"\n\x1e\x41RITHMETIC_OPERATOR_0_PREFIXED\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'enum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHOICE']._serialized_start=89
  _globals['_CHOICE']._serialized_end=137
  _globals['_ARITHMETICOPERATOR']._serialized_start=140
  _globals['_ARITHMETICOPERATOR']._serialized_end=287
  _globals['_TEST']._serialized_start=20
  _globals['_TEST']._serialized_end=87
# @@protoc_insertion_point(module_scope)
