# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: import_packages_same_name.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = ("Test",)


from dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False)
class Test(betterproto_fw.Message):
    """
    Tests generated message can correctly reference two packages with the same leaf-name
    """

    user: "users_v1.User" = betterproto_fw.message_field(1)
    """
    
    """

    post: "posts_v1.Post" = betterproto_fw.message_field(2)
    """
    
    """


from .posts import v1 as posts_v1
from .users import v1 as users_v1
