# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: messages.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "DoThingRequest",
    "DoThingResponse",
    "GetThingRequest",
    "GetThingResponse",
)


from datetime import datetime, timedelta
from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto_fw


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    comments: List[str] = betterproto_fw.string_field(2)
    """use `repeated` so we can check if `List` is correctly imported"""

    when: datetime = betterproto_fw.message_field(3)
    """
    use google types `timestamp` and `duration` so we can check
    if everything from `datetime` is correctly imported
    """

    duration: timedelta = betterproto_fw.message_field(4)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class DoThingResponse(betterproto_fw.Message):
    """ """

    names: List[str] = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingRequest(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class GetThingResponse(betterproto_fw.Message):
    """ """

    name: str = betterproto_fw.string_field(1)
    """
    
    """

    version: int = betterproto_fw.int32_field(2)
    """
    
    """
