# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: googletypes_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'googletypes_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19googletypes_request.proto\x12\x13googletypes_request\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x07\n\x05Input2\xd3\x06\n\x04Test\x12\x46\n\nSendDouble\x12\x1c.google.protobuf.DoubleValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendFloat\x12\x1b.google.protobuf.FloatValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendInt64\x12\x1b.google.protobuf.Int64Value\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendUInt64\x12\x1c.google.protobuf.UInt64Value\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendInt32\x12\x1b.google.protobuf.Int32Value\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendUInt32\x12\x1c.google.protobuf.UInt32Value\x1a\x1a.googletypes_request.Input\x12\x42\n\x08SendBool\x12\x1a.google.protobuf.BoolValue\x1a\x1a.googletypes_request.Input\x12\x46\n\nSendString\x12\x1c.google.protobuf.StringValue\x1a\x1a.googletypes_request.Input\x12\x44\n\tSendBytes\x12\x1b.google.protobuf.BytesValue\x1a\x1a.googletypes_request.Input\x12\x46\n\x0cSendDatetime\x12\x1a.google.protobuf.Timestamp\x1a\x1a.googletypes_request.Input\x12\x46\n\rSendTimedelta\x12\x19.google.protobuf.Duration\x1a\x1a.googletypes_request.Input\x12?\n\tSendEmpty\x12\x16.google.protobuf.Empty\x1a\x1a.googletypes_request.Inputb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'googletypes_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INPUT']._serialized_start=176
  _globals['_INPUT']._serialized_end=183
  _globals['_TEST']._serialized_start=186
  _globals['_TEST']._serialized_end=1037
# @@protoc_insertion_point(module_scope)
