# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x11service_uppercase\"0\n\x0e\x44oTHINGRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x63omments\x18\x02 \x03(\t\" \n\x0f\x44oTHINGResponse\x12\r\n\x05names\x18\x01 \x03(\t2X\n\x04Test\x12P\n\x07\x44oThing\x12!.service_uppercase.DoTHINGRequest\x1a\".service_uppercase.DoTHINGResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DOTHINGREQUEST']._serialized_start=36
  _globals['_DOTHINGREQUEST']._serialized_end=84
  _globals['_DOTHINGRESPONSE']._serialized_start=86
  _globals['_DOTHINGRESPONSE']._serialized_end=118
  _globals['_TEST']._serialized_start=120
  _globals['_TEST']._serialized_end=208
# @@protoc_insertion_point(module_scope)
