# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: float.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'float.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66loat.proto\x12\x05\x66loat\"\x99\x01\n\x04Test\x12\x10\n\x08positive\x18\x01 \x01(\x01\x12\x10\n\x08negative\x18\x02 \x01(\x01\x12\x0b\n\x03nan\x18\x03 \x01(\x01\x12\r\n\x05three\x18\x04 \x01(\x01\x12\x1c\n\x14three_point_one_four\x18\x05 \x01(\x01\x12\x11\n\tneg_three\x18\x06 \x01(\x01\x12 \n\x18neg_three_point_one_four\x18\x07 \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'float_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TEST']._serialized_start=23
  _globals['_TEST']._serialized_end=176
# @@protoc_insertion_point(module_scope)
