# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: oneof_enum.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Signal",
    "Test",
    "Move",
)


from dataclasses import dataclass

import betterproto


class Signal(betterproto.Enum):
    """ """

    PASS = 0
    """
    
    """

    RESIGN = 1
    """
    
    """


@dataclass(eq=False, repr=False)
class Test(betterproto.Message):
    """ """

    signal: "Signal" = betterproto.enum_field(1, group="action")
    """
    
    """

    move: "Move" = betterproto.message_field(2, group="action")
    """
    
    """


@dataclass(eq=False, repr=False)
class Move(betterproto.Message):
    """ """

    x: int = betterproto.int32_field(1)
    """
    
    """

    y: int = betterproto.int32_field(2)
    """
    
    """
