# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: repeatedmessage.proto
# plugin: python-betterproto
# This file has been @generated

__all__ = (
    "Test",
    "Sub",
)


from typing import (
    List,
)

from pydantic.dataclasses import dataclass

import betterproto


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Test(betterproto.Message):
    """ """

    greetings: List["Sub"] = betterproto.message_field(1)
    """
    
    """


@dataclass(eq=False, repr=False, config={"extra": "forbid"})
class Sub(betterproto.Message):
    """ """

    greeting: str = betterproto.string_field(1)
    """
    
    """
